@@ -4,6 +4,7 @@
 # SPDX-License-Identifier: GPL-2.0-or-later
 # License-Filename: LICENSE
 
+import datetime
 import os
 import re
 from contextlib import contextmanager
@@ -40,7 +41,7 @@ def is_task(line: str, *terms: str) -> bool:
     if re.search(r"^\s*#", line):
         return False
 
-    if "@" not in line:
+    if not re.search("(^|\s)@", line):
         return False
 
     if re.search("^x ", line):
